use std::path::Path;

use crate::string_type::String;
use mime_guess::Mime;

use crate::inspectors::mime_extension_lookup;

/// Information about a scanned file.
pub struct Findings<'a> {
	/// The location of the scanned file.
	pub file: &'a Path,
	/// Whether or not the file's extension is valid for its mimetype.
	pub valid: bool,
	/// The file's mimetype.
	pub mime: Mime,
}

impl<'a> Findings<'a> {
	pub fn recommended_extension(&self) -> Option<String> {
		mime_extension_lookup(self.mime.clone()).map(|extensions| extensions[0].to_owned())
	}
}
